SWDEV-1 - Skip tests hanging/failing in Windows PSDB
- Device side memory allocation & printf testcases are hanging because pcie atomics is disabled in recent builds - Few Coalesced Group testcases also hanging - Unit_Thread_Block_Getters_Positive_Basic testcase is failing randomly Change-Id: Ie53515db05c41e879248bb02655a74f0c296aa5f
This commit is contained in:
@@ -45,6 +45,12 @@ THE SOFTWARE.
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Unit_Printf_flags_Sanity_Positive") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
std::string reference(R"here(00000042
|
||||
-0000042
|
||||
00000042
|
||||
|
||||
@@ -41,6 +41,12 @@ THE SOFTWARE.
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_Buffered_Printf_Flags") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
std::string reference(R"here(00000042
|
||||
-0000042
|
||||
00000042
|
||||
|
||||
@@ -44,6 +44,12 @@ __global__ void run_printf(int *count) {
|
||||
* - HIP_VERSION >= 5.7
|
||||
*/
|
||||
TEST_CASE("Unit_Host_Printf") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
int *count{nullptr}, *count_d{nullptr};
|
||||
count = reinterpret_cast<int*>(malloc(sizeof(int)));
|
||||
HIP_CHECK(hipMalloc(&count_d, sizeof(int)));
|
||||
|
||||
@@ -44,6 +44,12 @@ THE SOFTWARE.
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Unit_Printf_length_Sanity_Positive") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
#if HT_NVIDIA
|
||||
std::string reference(R"here(-42 -42
|
||||
-42 -42
|
||||
|
||||
@@ -19,7 +19,7 @@
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
#include <hip_test_common.hh>
|
||||
|
||||
|
||||
|
||||
#define ITER_COUNT 61681
|
||||
#define KERNEL_ITERATIONS 15
|
||||
@@ -65,6 +65,12 @@ __global__ void kernel_printf_thread(int *count) {
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_NonHost_Printf_basic") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
int *count{nullptr}, *count_d{nullptr};
|
||||
|
||||
count = reinterpret_cast<int*>(malloc(sizeof(int)));
|
||||
@@ -93,6 +99,12 @@ TEST_CASE("Unit_NonHost_Printf_basic") {
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_NonHost_Printf_loop") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
int *count{nullptr}, *count_d{nullptr};
|
||||
|
||||
count = reinterpret_cast<int*>(malloc(ITER_COUNT * sizeof(int)));
|
||||
@@ -131,6 +143,12 @@ TEST_CASE("Unit_NonHost_Printf_loop") {
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_NonHost_Printf_multiple_Threads") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
int *count{nullptr}, *count_d{nullptr};
|
||||
|
||||
count = reinterpret_cast<int*>(malloc(ITER_COUNT_FOR_THREAD * sizeof(int)));
|
||||
@@ -172,6 +190,12 @@ TEST_CASE("Unit_NonHost_Printf_multiple_Threads") {
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_NonHost_Printf_BufferAvailability") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
int *count{nullptr}, *count_d{nullptr};
|
||||
|
||||
count = reinterpret_cast<int*>(malloc((ITER_COUNT-1) * sizeof(int)));
|
||||
|
||||
@@ -47,6 +47,12 @@ THE SOFTWARE.
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Unit_Printf_specifier_Sanity_Positive") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
#if HT_NVIDIA
|
||||
std::string reference(R"here(xyzzy
|
||||
%
|
||||
@@ -147,6 +153,12 @@ x
|
||||
* - HIP_VERSION >= 5.2
|
||||
*/
|
||||
TEST_CASE("Unit_Printf_Negative_Parameters_RTC") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
hiprtcProgram program{};
|
||||
|
||||
const auto program_source = kPrintfParam;
|
||||
|
||||
@@ -45,6 +45,12 @@ THE SOFTWARE.
|
||||
*/
|
||||
|
||||
TEST_CASE("Unit_Buffered_Printf_Specifier") {
|
||||
int pcieAtomic = 0;
|
||||
HIP_CHECK(hipDeviceGetAttribute(&pcieAtomic, hipDeviceAttributeHostNativeAtomicSupported, 0));
|
||||
if (!pcieAtomic) {
|
||||
HipTest::HIP_SKIP_TEST("Device doesn't support pcie atomic, Skipped");
|
||||
return;
|
||||
}
|
||||
#ifdef __HIP_PLATFORM_NVIDIA__
|
||||
std::string reference(R"here(xyzzy
|
||||
%
|
||||
|
||||
Reference in New Issue
Block a user